@@ -199,11 +199,6 @@ class AndroidSnowballSdConfig(AndroidBoardConfig, SnowballSdConfig):
         'earlyprintk mem=128M@0 mali.mali_mem=64M@128M hwmem=168M@192M mem=22M@360M mem_issw=1M@383M mem=640M@384M vmalloc=300M')
     _extra_serial_opts = 'console=ttyAMA2,115200n8'
     android_specific_args = 'init=/init androidboot.console=ttyAMA2'
-    # Snowball uses a custom uboot:
-    # it uses "fat load" instead of fatload and
-    # needs uImage/uInitrd prefixed with /
-    fatload_command = 'fat load'
-    uimage_path = '/'
     dtb_name = None
 
 
@@ -215,11 +210,6 @@ class AndroidSnowballEmmcConfig(AndroidBoardConfig, SnowballEmmcConfig):
     _extra_serial_opts = 'console=ttyAMA2,115200n8'
     android_specific_args = 'init=/init androidboot.console=ttyAMA2'
     mmc_option = '0:2'
-    # Snowball uses a custom uboot:
-    # it uses "fat load" instead of fatload and
-    # needs uImage/uInitrd prefixed with /
-    fatload_command = 'fat load'
-    uimage_path = '/'
     dtb_name = None
 
     @classmethod
