@@ -90,6 +90,18 @@ def align_partition(min_start, min_length, start_alignment, end_alignment):
     return start, end, length
 
 
+def copy_drop(src, dest_dir):
+    """Copy a file from src to destdir, dropping root ownership on the
+    way.
+    """
+    cmd = [ "cp", "-v",  src, dest_dir ]
+    cmd_runner.run(cmd, as_root=True).wait()
+
+    final = os.path.join(dest_dir, os.path.basename(src))
+    cmd = [ "chown", "%s:%s" % (os.getuid(), os.getgid()), final ]
+    cmd_runner.run(cmd, as_root=True).wait()
+
+
 class classproperty(object):
     """A descriptor that provides @property behavior on class methods."""
     def __init__(self, getter):
@@ -1354,17 +1366,13 @@ class FastModelConfig(BoardConfig):
     def _make_boot_files_v2(cls, boot_env, chroot_dir, boot_dir,
                          boot_device_or_file, k_img_data, i_img_data,
                          d_img_data):
-        logger = logging.getLogger("linaro_image_tools")
-        logger.info("WTF=%s." % boot_device_or_file )
         output_dir=os.path.dirname(boot_device_or_file)
-        cmd = [ "cp", "-v",  _get_file_matching("%s/boot/img.axf" % chroot_dir), output_dir ]
-        proc = cmd_runner.run(cmd, as_root=True)
-        proc.wait()
-        cmd = [ "cp", "-v",  k_img_data, i_img_data, d_img_data, output_dir ]
-        proc = cmd_runner.run(cmd, as_root=True)
-        proc.wait()
-        return
 
+        bootwrapper=_get_file_matching("%s/boot/img.axf" % chroot_dir)
+
+        for filename in (bootwrapper, k_img_data, i_img_data, d_img_data):
+            if filename != None:
+                copy_drop(filename, output_dir)
 
 class SamsungConfig(BoardConfig):
     @classproperty
@@ -1510,7 +1518,7 @@ class I386Config(BoardConfig):
     _live_serial_opts = 'serialtty=%s'
 
     # define kernel image
-    kernel_flavors = ['generic']
+    kernel_flavors = ['generic', 'pae']
 
     # define bootloader
     BOOTLOADER_CMD = 'grub-install'
@@ -1535,9 +1543,6 @@ class I386Config(BoardConfig):
     def _make_boot_files(cls, boot_env, chroot_dir, boot_dir,
                          boot_device_or_file, k_img_data, i_img_data,
                          d_img_data):
-        # XXX: delete this method when hwpacks V1 can die
-        assert cls.hwpack_format == HardwarepackHandler.FORMAT_1
-
         # copy image and init into boot partition
         cmd_runner.run(['cp', k_img_data, boot_dir], as_root=True).wait()
         cmd_runner.run(['cp', i_img_data, boot_dir], as_root=True).wait()
@@ -1564,6 +1569,15 @@ class I386Config(BoardConfig):
         cmd_runner.run(['cp', tmpfile, os.path.join(boot_dir,
             cls.BOOTLOADER_CFG_FILE)], as_root=True).wait()
 
+    @classmethod
+    def _make_boot_files_v2(cls, boot_env, chroot_dir, boot_dir,
+                            boot_device_or_file, k_img_data, i_img_data,
+                            d_img_data):
+        # reuse hwpack v1 function
+        cls._make_boot_files(boot_env, chroot_dir, boot_dir,
+                             boot_device_or_file, k_img_data, i_img_data,
+                             d_img_data)
+
 
 board_configs = {
     'beagle': BeagleConfig,
